@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class EntitiesConfig(AppConfig):
-    name = 'apis_entities'
+    name = 'apis_core.apis_entities'
